**********************************************************
* Set path
**********************************************************
clear

global path			"C:\Users\tx8\Dropbox\Stability Ambiguity Aversion\Submissions\JOEP\Data" //Enter working directory path here

cd "$path"

import excel labdata_raw_nov, sheet("all") firstrow clear
destring, replace

**********************************************************
* Genereal Comments
**********************************************************

* chosen urns in coin are urn 2 in session 3 and urn 2 in session 6 
* paytochange is rounded to 0.5 (This is the smallest marker on the grid of the sheet)
* Likert scales 0 to 4, with 0 ="ueberhaupt nicht sicher and 4 sehr sicher"
**********************************************************
* recode missings
**********************************************************
* Set missings to zero
* recode student econmajor semester game statistics econometrics height (. = 0) 

label variable yearofbirth "Year of Birth"
label variable student "1 if student"
label variable econmajor "1 if econmajor"
label variable semester "No of semersters stuied"
label variable game "1 if game theory taken"
label variable statistics "1 if stats taken"
label variable econometrics "1 if econometrics taken"
label variable height "Body height in cm"


**********************************************************
* label variables
**********************************************************
foreach i in 11 12 21 22 31 32 41 42{
label variable urne`i' "Choice urn`i', 1=up, 0=down"
label variable lkturne`i' "Likert scale urn`i', 0=not sure, 4=sure"
label variable paytochange`i' "Willingess to pay for changing bet in urn `i'"
}


label variable hl "hl, choose B first in row X, non-rational prefs=."
label variable sep "1 if sep subject"
label variable pilot "1 if pilot subject"
label variable id_sep "Id in Sep(301-600) & July/pilot(100-299)"

gen pre_sub=(id_sep!=.)
label variable pre_sub "1 if sep or pilot subject"

save interim, replace

clear

**********************************************************
* Merge in January data
**********************************************************
cd "$path"

import excel labdata_raw_jan, sheet("all") firstrow clear
destring, replace

merge 1:1 Id using interim
*merge 1:1 Id using "C:\Users\User\box\Stability Ambiguity Aversion\Daten\Januar 2013\labdata_jan.dta"
drop _merge


**********************************************************
* Drop Subjects of Jan session 1 beacause of wrong urn
**********************************************************

drop if Id_jan>1100&Id_jan<=1111


**********************************************************
* Generate corresponding urns
**********************************************************

gen remember_u1=0 if Id_jan!=.
gen remember_u2=0 if Id_jan!=.

label variable remember_u1 "1 if the urn that was chosen for PF payment is remembered correctly in Jan, decision 1"
label variable remember_u2 "1 if the urn that was chosen for PF payment is remembered correctly in Jan, decision 2"

replace remember_u1=1 if (remember_urne_old1==urne21)&(session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1
replace remember_u2=1 if (remember_urne_old2==urne22)&(session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1

replace remember_u1=1 if (remember_urne_old1==urne41)&(session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace remember_u2=1 if (remember_urne_old2==urne42)&(session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace remember_u1=1 if (remember_urne_old1==urne11)&((session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&(session==4)) // Group 3.1
replace remember_u2=1 if (remember_urne_old2==urne12)&((session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&(session==4)) // Group 3.1

replace remember_u1=1 if (remember_urne_old1==urne31)&((session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&(session==6)) // Group 3.2
replace remember_u2=1 if (remember_urne_old2==urne32)&((session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&(session==6)) // Group 3.2

replace remember_u1=. if remember_urne_old1==.
replace remember_u2=. if remember_urne_old2==.

gen remember_u51=0 
gen remember_u52=0

label variable remember_u51 "1 if the urn that became urn 5 is remembered correctly in Jan, decision 1"
label variable remember_u52 "1 if the urn that became urn 5 is remembered correctly in Jan, decision 2"

* Instructions inexact, hence we replace answers with missings
replace remember_u51=. if (remember_urne51==urne41)&(session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1
replace remember_u52=. if (remember_urne52==urne42)&(session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1

replace remember_u51=1 if (remember_urne51==urne31)&(session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace remember_u52=1 if (remember_urne52==urne32)&(session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

* Instructions inexact, hence we replace answers with missings
replace remember_u51=. if (remember_urne51==urne31)&(session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1
replace remember_u52=. if (remember_urne52==urne32)&(session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1

replace remember_u51=1 if (remember_urne51==urne41)&(session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2
replace remember_u52=1 if (remember_urne52==urne42)&(session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2


replace remember_u51=. if remember_urne51==.
replace remember_u52=. if remember_urne52==.


gen rem_tot=remember_u1+remember_u2+remember_u51+remember_u52 // This is to measure the # of bets remembered from Nov
label variable rem_tot "# of bets remembered from Nov - correct measure"

gen rem_tot5=remember_u51+remember_u52 // This is to measure the # of bets remembered from Nov
label variable rem_tot5 "# of FF bets remembered from Nov - correct measure"

gen rem_totPF=remember_u1+remember_u2 // This is to measure the # of bets remembered from Nov 
label variable rem_totPF "# of PF bets remembered from Nov - correct measure"

gen rem_all5=(rem_tot5==2) if rem_tot5!=. // This is to identify people that remember urn 5 correctly
label variable rem_all5 "1 if all urn 5 bets are remembered correct"

gen rem_allPF=(rem_totPF==2) if rem_totPF!=. // This is to identify people that remember urn 5 correctly
label variable rem_allPF "1 if all urn PF bets are remembered correct"

gen rem_all=(rem_allPF==1&rem_all5==1) if rem_totPF!=.&rem_tot5!=. // This is to identify people that both remembered correctly
label variable rem_allPF "1 if all urn bets are remembered correct"


************************************************************************************
* PP counterpart for nov urn
* this is to costruct the pysical counterpart to Jan urn in Nov for PP-FF comparison
************************************************************************************
gen Sub_novPP=.
label variable Sub_novPP "1 if subject is valid for novPP urn"
replace Sub_novPP=1 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1
replace Sub_novPP=1 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace Sub_novPP=1 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1
* Remember for Nov session 6 (Group 3.2) there is no PP-FF comparison

gen urne_novPP1=.
gen urne_novPP2=.

label variable urne_novPP1 "PP choice for Phys ident Nov urn to Jan urn 5, decision 1"
label variable urne_novPP2 "PP choice for Phys ident Nov urn to Jan urn 5, decision 2"

replace urne_novPP1=urne41 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1
replace urne_novPP2=urne42 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1

replace urne_novPP1=urne21 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace urne_novPP2=urne22 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace urne_novPP1=urne41 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1
replace urne_novPP2=urne42 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1
* Remember for Nov session 6 (Group 3.2) there is no PP-FF comparison

gen lkturne_novPP1=.
gen lkturne_novPP2=.

label variable lkturne_novPP1 "lkt PP choice for Phys ident Nov urn to Jan urn 5, decision 1"
label variable lkturne_novPP2 "lkt PP choice for Phys ident Nov urn to Jan urn 5, decision 2"

replace lkturne_novPP1=lkturne41 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1
replace lkturne_novPP2=lkturne42 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1

replace lkturne_novPP1=lkturne21 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace lkturne_novPP2=lkturne22 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace lkturne_novPP1=lkturne41 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1
replace lkturne_novPP2=lkturne42 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1


gen paytochange_novPP1=.
gen paytochange_novPP2=.

label variable paytochange_novPP1 "WTC PP choice for Phys ident Nov urn to Jan urn 5, decision 1"
label variable paytochange_novPP2 "WTC PP choice for Phys ident Nov urn to Jan urn 5, decision 2"

replace paytochange_novPP1=paytochange41 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1
replace paytochange_novPP2=paytochange42 if (session_jan==1|session_jan==2|session_jan==3|session_jan==11|session_jan==14) // Group 1

replace paytochange_novPP1=paytochange21 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace paytochange_novPP2=paytochange22 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace paytochange_novPP1=paytochange41 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1
replace paytochange_novPP2=paytochange42 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==4 // Group 3.1




************************************************************************************
* PF counterpart for nov urn
* this is to costruct the pysical counterpart to Jan urn in Nov for PF-FF comparison
************************************************************************************

gen Sub_novPF=.
label variable Sub_novPF "1 if subject is valid for novPF urn"
replace Sub_novPF=1 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace Sub_novPF=1  if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2

gen urne_novPF1=.
gen urne_novPF2=.

label variable urne_novPF1 "PF choice for Phys ident Nov urn to Jan urn 5, decision 1"
label variable urne_novPF2 "PF choice for Phys ident Nov urn to Jan urn 5, decision 2"

replace urne_novPF1=urne31 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace urne_novPF2=urne32 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace urne_novPF1=urne41 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2
replace urne_novPF2=urne42 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2

* Remember for Nov session 6 (Group 3.2) there is no PP-FF comparison

gen lkturne_novPF1=.
gen lkturne_novPF2=.

label variable lkturne_novPF1 "lkt PF choice for Phys ident Nov urn to Jan urn 5, decision 1"
label variable lkturne_novPF2 "lkt PF choice for Phys ident Nov urn to Jan urn 5, decision 2"

replace lkturne_novPF1=lkturne31 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace lkturne_novPF2=lkturne32 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace lkturne_novPF1=lkturne41 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2
replace lkturne_novPF2=lkturne42 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2


gen paytochange_novPF1=.
gen paytochange_novPF2=.

label variable paytochange_novPF1 "WTC PF choice for Phys ident Nov urn to Jan urn 5, decision 1"
label variable paytochange_novPF2 "WTC PF choice for Phys ident Nov urn to Jan urn 5, decision 2"

replace paytochange_novPF1=paytochange31 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2
replace paytochange_novPF2=paytochange32 if (session_jan==4|session_jan==5|session_jan==6|session_jan==10) // Group 2

replace paytochange_novPF1=paytochange41 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2
replace paytochange_novPF2=paytochange42 if (session_jan==7|session_jan==8|session_jan==9|session_jan==12|session_jan==13)&session==6 // Group 3.2



**********************************************************
* Generate APrefs for corresponding urns
**********************************************************

foreach i in _novPP _novPF 5 6{
gen AA_urne`i'= 0 if (urne`i'1!=.&urne`i'2!=.)
replace AA_urne`i'=1 if (urne`i'1==1&urne`i'2==0) //ambiguity averse choice in urn i
label variable AA_urne`i' "Ambiguity averse choice in urn `i'"

gen AN_urne`i'= 0 if (urne`i'1!=.&urne`i'2!=.)
replace AN_urne`i'=1 if ((urne`i'1==1&urne`i'2==1)|(urne`i'1==0&urne`i'2==0)) //ambiguity neutral choice in urn i
label variable AN_urne`i' "Ambiguity neutral choice in urn `i'"

gen AL_urne`i'=0 if (urne`i'1!=.&urne`i'2!=.)
replace AL_urne`i'=1 if ((urne`i'1==0&urne`i'2==1)) //ambiguity loving choice in urn i
label variable AL_urne`i' "Ambiguity loving choice in urn `i'"

gen AP_urne`i'=.
replace AP_urne`i'=-1 if  AA_urne`i'==1
replace AP_urne`i'=0 if  AN_urne`i'==1
replace AP_urne`i'=1 if  AL_urne`i'==1
label variable AP_urne`i' "Ambiguity Preference in urn `i'"
}


replace Sub_novPP=. if AP_urne_novPP==.
replace Sub_novPF=. if AP_urne_novPF==.
**********************************************************
* Generate dummy variables
**********************************************************

* consistent from Nov to Jan
gen cons_AP_u5_Nov_Jan=(AP_urne5==AP_urne_novPP) if Id_jan!=.
label variable cons_AP_u5_Nov_Jan "1 if same prefs from Nov to Jan in same urn"

gen cons_choice_u5_Nov_Jan=(urne51==urne_novPP1&urne52==urne_novPP2) if Id_jan!=.
label variable cons_choice_u5_Nov_Jan "1 if same choices from Nov to Jan in same urn"

* HL consistency
gen cons_hl_Nov_Jan=(abs(hl-hl_jan)<2) if Id_jan!=.&hl!=.
label variable cons_hl_Nov_Jan "1 if stable Risk prefs Nov Jan"
replace cons_hl_Nov_Jan=. if hl==.|hl_jan==.
replace cons_hl_Nov_Jan=. if Id_jan==.


* Randomization dummy
gen interim=.
replace interim =0 if randomization =="PP_PF"
replace interim =1 if randomization =="PF_PP"
drop randomization
gen randomization = interim
label variable randomization "0=PP_PF, 1=PF_PP"
label define randomization_name 0 "PP_PF" 1 "PF_PP"
label values randomization randomization_name
*label define foreignl 0 "domestic car" 1 "foreign car"
drop interim

* denote future and present urns
gen urnePP11=.
gen urnePP12=.
gen paytochangePP11=.
gen paytochangePP12=.
gen lktPP11=.
gen lktPP12=.

gen urnePP21=.
gen urnePP22=.
gen paytochangePP21=.
gen paytochangePP22=.
gen lktPP21=.
gen lktPP22=.

gen urnePF11=.
gen urnePF12=.
gen paytochangePF11=.
gen paytochangePF12=.
gen lktPF11=.
gen lktPF12=.

gen urnePF21=.
gen urnePF22=.
gen paytochangePF21=.
gen paytochangePF22=.
gen lktPF21=.
gen lktPF22=.


label variable urnePP11 		"Present urn 1 1st choice"
label variable urnePP12 		"Present urn 1 2nd choice"
label variable paytochangePP11 	"Present urn 1  WTA 1st choice"
label variable paytochangePP12 	"Present urn 1  WTA 2nd choice"
label variable lktPP11 			"Present urn 1 confidence 1st choice"
label variable lktPP12 			"Present urn 1 confidence 2nd choice"

label variable urnePP21 		"Present urn 2 1st choice"
label variable urnePP22 		"Present urn 2 2nd choice"
label variable paytochangePP21  "Present urn 2 WTA 1st choice" 
label variable paytochangePP22  "Present urn 2 WTA 2nd choice"
label variable lktPP21 			"Present urn 2 confidence 1st choice"
label variable lktPP22 			"Present urn 2 confidence 2nd choice"

label variable urnePF11 		"Future urn 1 1st choice today"
label variable urnePF12 		"Future urn 1 2nd choice today"
label variable paytochangePF11 	"Future urn 1 WTA 1st choice today"
label variable paytochangePF12 	"Future urn 1 WTA 2nd choice today"
label variable lktPF11 			"Future urn 1 confidence 1st choice"
label variable lktPF12 			"Future urn 1 confidence 2nd choice"

label variable urnePF21 		"Future urn 2 1st choice today"
label variable urnePF22 		"Future urn 2 2nd choice today"
label variable paytochangePF21 	"Future urn 2 WTA 1st choice today"
label variable paytochangePF22 	"Future urn 2 WTA 2nd choice today"
label variable lktPF21 			"Future urn 2 confidence 1st choice"
label variable lktPF22 			"Future urn 2 confidence 2nd choice"

foreach i in 1 2 {

replace urnePP1`i'=urne1`i' 				if randomization ==0
replace urnePP2`i'=urne2`i' 				if randomization ==0
replace paytochangePP1`i'=paytochange1`i' 	if randomization ==0
replace paytochangePP2`i'=paytochange2`i' 	if randomization ==0
replace lktPP1`i'=lkturne1`i' 				if randomization ==0
replace lktPP2`i'=lkturne2`i' 				if randomization ==0

replace urnePF1`i'=urne3`i' 				if randomization ==0
replace urnePF2`i'=urne4`i' 				if randomization ==0
replace paytochangePF1`i'=paytochange3`i' 	if randomization ==0
replace paytochangePF2`i'=paytochange4`i' 	if randomization ==0
replace lktPF1`i'=lkturne3`i' 				if randomization ==0
replace lktPF2`i'=lkturne4`i' 				if randomization ==0

replace urnePP1`i'=urne3`i' 				if randomization ==1
replace urnePP2`i'=urne4`i' 				if randomization ==1
replace paytochangePP1`i'=paytochange3`i' 	if randomization ==1
replace paytochangePP2`i'=paytochange4`i' 	if randomization ==1
replace lktPP1`i'=lkturne3`i' 				if randomization ==1
replace lktPP2`i'=lkturne4`i' 				if randomization ==1

replace urnePF1`i'=urne1`i' 				if randomization ==1
replace urnePF2`i'=urne2`i' 				if randomization ==1
replace paytochangePF1`i'=paytochange1`i' 	if randomization ==1
replace paytochangePF2`i'=paytochange2`i' 	if randomization ==1
replace lktPF1`i'=lkturne1`i' 				if randomization ==1
replace lktPF2`i'=lkturne2`i' 				if randomization ==1
}


**********************************************************
* Identify physically identical urns
**********************************************************

* Strategy of comparison: urnPF21, urnPP21 is fixed, create variable urnPP31, urnPP32 that denotes the phsyical counterpart 
* (urnPP31, etc, denotes the decision in the first question for the urn that later became urn 3, split up by treatment (PP-PF  or PF-PP)
* Note: This comparison is agnostic regarding the randomization order


gen urnePP31=.
gen paytochangePP31=.
gen lktPP31=.
label variable urnePP31	"Present urn choice 1, physical indent urn"

gen urnePP32=.
gen paytochangePP32=.
gen lktPP32=.
label variable urnePP32	"Present urn choice 2, physical indent urn"

gen urnePF31=.
gen paytochangePF31=.
gen lktPF31=.
label variable urnePF31	"Future urn choice 1, physical indent urn"

gen urnePF32=.
gen paytochangePF32=.
gen lktPF32=.
label variable urnePF32	"Future urn choice 2, physical indent urn"

* urne3 is always one of the physically identical urns, 
* Note: randomization=0 for PP_PF

replace urnePF31=urne31 		if randomization==0 //PP_PF
replace urnePF32=urne32 		if randomization==0 //PP_PF
* These variables contain the moved urn for all sessions with PF_PP, or the original 

replace urnePP31=urne31 		if randomization==1 //PF_PP
replace urnePP32=urne32 		if randomization==1 //PF_PP



* Session N1 PF-PP, urn 1 is transferred, urn1 =urn3, PF1=PF3
* Other info: drwan balls: blue, yellow, HL, row: 8, side: 8, discount: 9

replace urnePF31=urnePF11 				if session==1
replace paytochangePF31=paytochangePF11 if session==1
replace lktPF31=lktPF11 				if session==1

replace urnePF32=urnePF12 				if session==1
replace paytochangePF32=paytochangePF12 if session==1
replace lktPF32=lktPF12 				if session==1

* Session N2 PP-PF, urn 2 is transferred, urn2 =urn3, PP2=PP3
* Other info: drwan balls: blue, green, HL, row: 9, side: 1, discount: 10
replace urnePP31=urnePP21 				if session==2
replace paytochangePP31=paytochangePP21 if session==2
replace lktPP31=lktPP21 				if session==2

replace urnePP32=urnePP22 				if session==2
replace paytochangePP32=paytochangePP22 if session==2
replace lktPP32=lktPP22 				if session==2

* Session N3 PP-PF, urn 2 is transferred, urn2 =urn3, PP2=PP3
* Other info: drwan balls: yellow, yellow, HL, row: 8, side: 6, discount: 6
replace urnePP31=urnePP21 				if session==3
replace paytochangePP31=paytochangePP21 if session==3
replace lktPP31=lktPP21 				if session==3

replace urnePP32=urnePP22 				if session==3
replace paytochangePP32=paytochangePP22 if session==3
replace lktPP32=lktPP12 				if session==3

* Session N4 PF-PP, urn 2 is transferred, urn2 =urn3, PF2=PF3
* Other info: drwan balls: green, green, HL, row: 2, side: 7, discount: 1
replace urnePF31=urnePF21 				if session==4
replace paytochangePF31=paytochangePF21 if session==4
replace lktPF31=lktPF21 				if session==4

replace urnePF32=urnePF22 				if session==4
replace paytochangePF32=paytochangePF22 if session==4
replace lktPF32=lktPF22 				if session==4

* Session N5 PF-PP, urn 1 is transferred, urn1 =urn3, PF1=PF3
* Other info: drwan balls: green, yellow, HL, row: 8, side: 1, discount: 1
replace urnePF31=urnePF11 				if session==5
replace paytochangePF31=paytochangePF11 if session==5
replace lktPF31=lktPF11 				if session==5

replace urnePF32=urnePF12 				if session==5
replace paytochangePF32=paytochangePF12 if session==5
replace lktPF32=lktPF12 				if session==5

* Session N6 PP-PF, urn 1 is transferred, urn1 =urn3, PP1=PP3
* Other info: drwan balls: blue, blue, HL, row: 8, side: 9, discount: 9
replace urnePP31=urnePP11 				if session==6
replace paytochangePP31=paytochangePP11 if session==6
replace lktPP31=lktPP11 				if session==6

replace urnePP32=urnePP12 				if session==6
replace paytochangePP32=paytochangePP12 if session==6
replace lktPP32=lktPP12 				if session==6

**********************************************************
* Define Holt/Laury confusion and inconsistency
**********************************************************

gen hl_inconsistent=(hl==.)
label variable hl_inconsistent "hl non-rational"

gen hl_confused=(hl==11)
label variable hl_confused "hl, choose option A in row 10"

gen hl_outlier=(hl_inconsistent==1|hl_confused==1)
label variable hl_outlier "1 if in hl inconsistent or confused"

* Note this variable accounts for the fact that subjects could be indifferent between two rows
* Inconsistency is definded s.t. deviation between 1st and 2nd choice is greater 2


gen hl_jan_inconsistent=(hl_jan==.)
label variable hl_inconsistent "hl non-rational"

gen hl_jan_confused=(hl_jan==11)
label variable hl_confused "hl, choose option A in row 10"

gen hl_jan_outlier=(hl_jan_inconsistent==1|hl_jan_confused==1)
label variable hl_outlier "1 if in hl inconsistent or confused"

**********************************************************
* Define Ambiguity Preferences
**********************************************************
* preferences over numbered urns**************************
foreach i in 1 2 3 4{
gen AA_urne`i'=0 if urne`i'1!=.&urne`i'2!=.
replace AA_urne`i'=1 if urne`i'1==1&urne`i'2==0 //ambiguity averse choice in urn i
label variable AA_urne`i' "Ambiguity averse choice in urn `i'"

gen AN_urne`i'=0 if urne`i'1!=.&urne`i'2!=.
replace AN_urne`i'=1 if ((urne`i'1==1&urne`i'2==1)|(urne`i'1==0&urne`i'2==0)) //ambiguity neutral choice in urn i
label variable AN_urne`i' "Ambiguity neutral choice in urn `i'"

gen AL_urne`i'=0 if urne`i'1!=.&urne`i'2!=.
replace AL_urne`i'=1 if ((urne`i'1==0&urne`i'2==1)) //ambiguity loving choice in urn i
label variable AL_urne`i' "Ambiguity loving choice in urn `i'"

gen AP_urne`i'=.
replace AP_urne`i'=-1 if  AA_urne`i'==1
replace AP_urne`i'=0 if  AN_urne`i'==1
replace AP_urne`i'=1 if  AL_urne`i'==1
label variable AP_urne`i' "Ambiguity Preference in urn `i'"
}




* preferences over PP,PF urns*****************************
************ urns PP1, PP2, PF1, PF2**********************

foreach i in 1 2{

gen AA_urnePP`i'=0 if urnePP`i'1!=.&urnePP`i'2!=.
replace AA_urnePP`i'=1 if (urnePP`i'1==1&urnePP`i'2==0) //ambiguity averse choice in urn i
label variable AA_urnePP`i' "PP Ambiguity averse choice in urn `i'"

gen AN_urnePP`i'=0 if urnePP`i'1!=.&urnePP`i'2!=.
replace AN_urnePP`i'=1 if ((urnePP`i'1==1&urnePP`i'2==1)|(urnePP`i'1==0&urnePP`i'2==0)) //ambiguity neutral choice in urn i
label variable AN_urnePP`i' "Ambiguity neutral choice in urn `i'"

gen AL_urnePP`i'=0 if urnePP`i'1!=.&urnePP`i'2!=.
replace AL_urnePP`i'=1 if ((urnePP`i'1==0&urnePP`i'2==1)) //ambiguity loving choice in urn i
label variable AL_urnePP`i' "Ambiguity loving choice in urn `i'"

gen AA_urnePF`i'=0 if urnePF`i'1!=.&urnePF`i'2!=.
replace AA_urnePF`i'=1 if (urnePF`i'1==1&urnePF`i'2==0) //ambiguity averse choice in urn i
label variable AA_urnePF`i' "PF Ambiguity averse choice in urn `i'"

gen AN_urnePF`i'=0 if urnePF`i'1!=.&urnePF`i'2!=.
replace AN_urnePF`i'=1 if ((urnePF`i'1==1&urnePF`i'2==1)|(urnePF`i'1==0&urnePF`i'2==0)) //ambiguity neutral choice in urn i
label variable AN_urnePF`i' "Ambiguity neutral choice in urn `i'"

gen AL_urnePF`i'=0 if urnePF`i'1!=.&urnePF`i'2!=.
replace AL_urnePF`i'=1 if ((urnePF`i'1==0&urnePF`i'2==1)) //ambiguity loving choice in urn i
label variable AL_urnePP`i' "Ambiguity loving choice in urn `i'"

gen AP_urnePP`i'=.
replace AP_urnePP`i'=-1 if  AA_urnePP`i'==1
replace AP_urnePP`i'=0 if  AN_urnePP`i'==1
replace AP_urnePP`i'=1 if  AL_urnePP`i'==1
label variable AP_urnePP`i' "PP Ambiguity Preference in urn `i'"

gen AP_urnePF`i'=.
replace AP_urnePF`i'=-1 if  AA_urnePF`i'==1
replace AP_urnePF`i'=0 if  AN_urnePF`i'==1
replace AP_urnePF`i'=1 if  AL_urnePF`i'==1
label variable AP_urnePF`i' "PF Ambiguity Preference in urn `i'"
}

************ mean PP, PF, FF**********************

gen AN_urnePP = 0.5*(AN_urnePP1+AN_urnePP2)
gen AN_urnePF = 0.5*(AN_urnePF1+AN_urnePF2)
gen AN_urneFF = 0.5*(AN_urne5+AN_urne6)

gen AL_urnePP = 0.5*(AL_urnePP1+AL_urnePP2)
gen AL_urnePF = 0.5*(AL_urnePF1+AL_urnePF2)
gen AL_urneFF = 0.5*(AL_urne5+AL_urne6)

gen AA_urnePP = 0.5*(AA_urnePP1+AA_urnePP2)
gen AA_urnePF = 0.5*(AA_urnePF1+AA_urnePF2)
gen AA_urneFF = 0.5*(AA_urne5+AA_urne6)

************ mean PP, PF, FF**********************

gen AN_pair1 = 0.5*(AN_urne1+AN_urne2)
gen AN_pair2 = 0.5*(AN_urne3+AN_urne4)
gen AN_pair3 = 0.5*(AN_urne5+AN_urne6)

gen AL_pair1 = 0.5*(AN_urne1+AN_urne2)
gen AL_pair2 = 0.5*(AN_urne3+AN_urne4)
gen AL_pair3 = 0.5*(AL_urne5+AL_urne6)

gen AA_pair1 = 0.5*(AN_urne1+AN_urne2)
gen AA_pair2 = 0.5*(AN_urne3+AN_urne4)
gen AA_pair3 = 0.5*(AA_urne5+AA_urne6)


************ urns PP3, PF3*********************************

gen AA_urnePP3=0 if urnePP31!=.&urnePP32!=.
replace AA_urnePP3=1 if (urnePP31==1&urnePP32==0) //ambiguity averse choice in urn i, physically indetial urn
label variable AA_urnePP3 "PP Ambiguity averse choice in physically indetial urn"

gen AN_urnePP3=0 if urnePP31!=.&urnePP32!=.
replace AN_urnePP3=1 if ((urnePP31==1&urnePP32==1)|(urnePP31==0&urnePP32==0)) //ambiguity neutral choice in urn i, physically indetial urn
label variable AN_urnePP3 "Ambiguity neutral choice in physically indetial urn"

gen AL_urnePP3=0 if urnePP31!=.&urnePP32!=.
replace AL_urnePP3=1 if ((urnePP31==0&urnePP32==1)) //ambiguity loving choice in urn 3, physically indetial urn
label variable AL_urnePP3 "Ambiguity loving choice in physically indetial urn"

gen AP_urnePP3=.
replace AP_urnePP3=-1 if  AA_urnePP3==1
replace AP_urnePP3=0 if  AN_urnePP3==1
replace AP_urnePP3=1 if  AL_urnePP3==1
label variable AP_urnePP3 "PP Ambiguity Preference in physically indetial urn"

gen AA_urnePF3=0 if urnePF31!=.&urnePF32!=.
replace AA_urnePF3=1 if (urnePF31==1&urnePF32==0) //ambiguity averse choice in urn i, physically indetial urn
label variable AA_urnePF3 "PP Ambiguity averse choice in physically indetial urn"

gen AN_urnePF3=0 if urnePF31!=.&urnePF32!=.
replace AN_urnePF3=((urnePF31==1&urnePF32==1)|(urnePF31==0&urnePF32==0)) //ambiguity neutral choice in urn i, physically indetial urn
label variable AN_urnePF3 "Ambiguity neutral choice in physically indetial urn"

gen AL_urnePF3=0 if urnePF31!=.&urnePF32!=.
replace AL_urnePF3=1 if ((urnePF31==0&urnePF32==1)) //ambiguity loving choice in urn 3, physically indetial urn
label variable AL_urnePF3 "Ambiguity loving choice in physically indetial urn"

gen AP_urnePF3=.
replace AP_urnePF3=-1 if  AA_urnePF3==1
replace AP_urnePF3=0 if  AN_urnePF3==1
replace AP_urnePF3=1 if  AL_urnePF3==1
label variable AP_urnePF3 "PF Ambiguity Preference in physically indetial urn"


**********************************************************
* Generate dummies for stability
**********************************************************

* same choices *******************************************
gen consC_tot=0 if (urne11!=.&urne21!=.&urne31!=.&urne41!=.&urne12!=.&urne22!=.&urne32!=.&urne42!=.) // compare consistency of choices over urns
replace consC_tot=(urne11==urne21&urne21==urne41&urne31==urne41&urne12==urne22&urne22==urne42&urne32==urne42) if urne11!=.&urne21!=.&urne31!=.&urne41!=.&urne12!=.&urne22!=.&urne32!=.&urne42!=. // compare consistency of choices over urns
label variable consC_tot "1 if subjects have same chioce over all urns"

gen consC_1_2_4=0 if (urne11!=.&urne21!=.&urne41!=.&urne12!=.&urne22!=.&urne42!=.)
replace consC_1_2_4=(urne11==urne21&urne21==urne41&urne12==urne22&urne22==urne42) if (urne11!=.&urne21!=.&urne41!=.&urne12!=.&urne22!=.&urne42!=.)
label variable consC_1_2_4 "1 if subjects have same chioce over urns 1 2 4"

gen consC_1_2=0 if urne11!=.&urne21!=.&urne12!=.&urne22
replace consC_1_2=(urne11==urne21&urne12==urne22) if urne11!=.&urne21!=.&urne12!=.&urne22

gen consC_2_3=0 if urne31!=.&urne21!=.&urne32!=.&urne22
replace consC_2_3=(urne21==urne31&urne32==urne22) if urne31!=.&urne21!=.&urne32!=.&urne22

gen consC_3_4=0 if urne31!=.&urne41!=.&urne32!=.&urne42
replace consC_3_4=(urne31==urne41&urne32==urne42) if urne31!=.&urne41!=.&urne32!=.&urne42

label variable consC_1_2 "1 if subjects have same chioce over urns 1 2"
label variable consC_2_3 "1 if subjects have same chioce over urns 2 3"
label variable consC_3_4 "1 if subjects have same chioce over urns 3 4"

gen consC_PP=0 if AP_urnePP1!=.&AP_urnePP2!=.
replace consC_PP=(urnePP11==urnePP21&urnePP12==urnePP22) if AP_urnePP1!=.&AP_urnePP2!=.

gen consC_PF=0 if AP_urnePF1!=.&AP_urnePF2!=.
replace consC_PF=(urnePF11==urnePF21&urnePF12==urnePF22) if AP_urnePF1!=.&AP_urnePF2!=.


label variable consC_PP "1 if subjects have same chioce over urns PP"
label variable consC_PF "1 if subjects have same chioce over urns PF"

gen consC_PP_PF=(urnePF31==urnePP31&urnePF32==urnePP32) if urnePF31!=.&urnePP31!=.&urnePF32!=.&urnePP32!=.
label variable consC_PP_PF "1 if subjects have same choice over phys ident urn PP PF"

* same preferences ****************************************
gen consAA_tot=(AA_urne1==AA_urne2&AA_urne1==AA_urne3&AA_urne3==AA_urne4)
gen consAA_1_2_4=(AA_urne1==AA_urne2&AA_urne1==AA_urne4)
gen consAA_1_2=(AA_urne1==AA_urne2)
gen consAA_1_3=(AA_urne1==AA_urne3)
gen consAA_1_4=(AA_urne1==AA_urne4)
gen consAA_2_3=(AA_urne2==AA_urne3)
gen consAA_2_4=(AA_urne2==AA_urne4)
gen consAA_3_4=(AA_urne3==AA_urne4)
gen consAA_same=(AA_urnePP3==AA_urnePF3)

label variable consAA_tot "1 if subjects are AA over all urns"
label variable consAA_1_2_4 "1 if subjects are AA over urns 1 2 4"
label variable consAA_1_2 "1 if subjects are AA over urns 1 2"
label variable consAA_1_3 "1 if subjects are AA over urns 1 3"
label variable consAA_1_4 "1 if subjects are AA over urns 1 4"
label variable consAA_2_3 "1 if subjects are AA over urns 2 3"
label variable consAA_2_4 "1 if subjects are AA over urns 2 4"
label variable consAA_3_4 "1 if subjectsare AA over urns 3 4"
label variable consAA_same "1 if subjects are AA over identical urn"

gen consAN_tot=(AN_urne1==AN_urne2&AN_urne1==AN_urne3&AN_urne3==AN_urne4)
gen consAN_1_2_4=(AN_urne1==AN_urne2&AN_urne1==AN_urne4)
gen consAN_1_2=(AN_urne1==AN_urne2)
gen consAN_1_3=(AN_urne1==AN_urne3)
gen consAN_1_4=(AN_urne1==AN_urne4)
gen consAN_2_3=(AN_urne2==AN_urne3)
gen consAN_2_4=(AN_urne2==AN_urne4)
gen consAN_3_4=(AN_urne3==AN_urne4)
gen consAN_same=(AN_urnePP3==AN_urnePF3)

label variable consAN_tot "1 if subjects are AN over all urns"
label variable consAN_1_2_4 "1 if subjects are AN over urns 1 2 4"
label variable consAN_1_2 "1 if subjects are AN over urns 1 2"
label variable consAN_1_3 "1 if subjects are AN over urns 1 3"
label variable consAN_1_4 "1 if subjects are AN over urns 1 4"
label variable consAN_2_3 "1 if subjects are AN over urns 2 3"
label variable consAN_2_4 "1 if subjects are AN over urns 2 4"
label variable consAN_3_4 "1 if subjects are AN over urns 3 4"
label variable consAN_same "1 if subjects are AN over identical urn"

gen consAL_tot=(AL_urne1==AL_urne2&AL_urne1==AL_urne3&AL_urne3==AL_urne4)
gen consAL_1_2_4=(AL_urne1==AL_urne2&AL_urne1==AL_urne4)
gen consAL_1_2=(AL_urne1==AL_urne2)
gen consAL_1_3=(AL_urne1==AL_urne3)
gen consAL_1_4=(AL_urne1==AL_urne4)
gen consAL_2_3=(AL_urne2==AL_urne3)
gen consAL_2_4=(AL_urne2==AL_urne4)
gen consAL_3_4=(AL_urne3==AL_urne4)
gen consAL_same=(AL_urnePP3==AL_urnePF3)

label variable consAL_tot "1 if subjects are AL over all urns"
label variable consAL_1_2_4 "1 if subjects are AL over urns 1 2 4"
label variable consAL_1_2 "1 if subjects are AL over urns 1 2"
label variable consAL_1_3 "1 if subjects are AL over urns 1 3"
label variable consAL_1_4 "1 if subjects are AL over urns 1 4"
label variable consAL_2_3 "1 if subjects are AL over urns 2 3"
label variable consAL_2_4 "1 if subjects are AL over urns 2 4"
label variable consAL_3_4 "1 if subjects are AL over urns 3 4"
label variable consAL_same "1 if subjects are AL over identical urn"

gen consP_tot=0 if (AP_urne2!=.&AP_urne1!=.&AP_urne3!=.&AP_urne4!=.)
replace consP_tot=(AP_urne1==AP_urne2&AP_urne1==AP_urne3&AP_urne3==AP_urne4) if (AP_urne2!=.&AP_urne1!=.&AP_urne3!=.&AP_urne4!=.)

*gen cons_tot=0 if (AP_urne2!=.&AP_urne1!=.&AP_urne3!=.&AP_urne4!=.)&coin==1
*gen cons_tot=0 if (AP_urne2!=.&AP_urne1!=.&AP_urne3!=.&AP_urne4!=.&AP_urne5!=.&AP_urne6!=.)&coin==0


replace consP_tot=(AP_urne1==AP_urne2&AP_urne1==AP_urne3&AP_urne3==AP_urne4) 


gen consP_1_2_4=(AP_urne1==AP_urne2&AP_urne1==AP_urne4)
replace consP_1_2_4=(AP_urne1==AP_urne2&AP_urne1==AP_urne4)

gen consP_1_2=0 if (AP_urne1!=.&AP_urne2!=.)
replace consP_1_2=(AP_urne1==AP_urne2)  if (AP_urne1!=.&AP_urne2!=.)

gen consP_1_3=0 if (AP_urne1!=.&AP_urne3!=.)
replace consP_1_3=(AP_urne1==AP_urne3) if (AP_urne1!=.&AP_urne3!=.)

gen consP_1_4=0 if (AP_urne1!=.&AP_urne4!=.)
replace consP_1_4=(AP_urne1==AP_urne4)  if (AP_urne1!=.&AP_urne4!=.)

gen consP_2_3=0  if (AP_urne2!=.&AP_urne3!=.)
replace consP_2_3=(AP_urne2==AP_urne3)  if (AP_urne2!=.&AP_urne2!=.)

gen consP_2_4=0  if (AP_urne2!=.&AP_urne4!=.)
replace consP_2_4=(AP_urne2==AP_urne4)  if (AP_urne2!=.&AP_urne4!=.)

gen consP_3_4=0 if (AP_urne3!=.&AP_urne4!=.)
replace consP_3_4=(AP_urne3==AP_urne4) if (AP_urne3!=.&AP_urne4!=.)


gen consP_PP1_PF1=0 if (AP_urnePP1!=.&AP_urnePF1!=.)
replace consP_PP1_PF1=(AP_urnePP1==AP_urnePF1) if (AP_urnePP1!=.&AP_urnePF1!=.)

gen consP_PP1_PF2=0 if (AP_urnePP1!=.&AP_urnePF2!=.)
replace consP_PP1_PF2=(AP_urnePP1==AP_urnePF2) if (AP_urnePP1!=.&AP_urnePF2!=.)

gen consP_PP2_PF1=0 if (AP_urnePP2!=.&AP_urnePF1!=.)
replace consP_PP2_PF1=(AP_urnePP2==AP_urnePF1) if (AP_urnePP2!=.&AP_urnePF1!=.)

gen consP_PP2_PF2=0 if (AP_urnePP2!=.&AP_urnePF2!=.)
replace consP_PP2_PF2=(AP_urnePP2==AP_urnePF2) if (AP_urnePP2!=.&AP_urnePF2!=.)

gen consP_PP3_PF3=0 if (AP_urnePP3!=.&AP_urnePF3!=.)
replace consP_PP3_PF3=(AP_urnePP3==AP_urnePF3) if (AP_urnePP3!=.&AP_urnePF3!=.)
gen consP_PP_PF=(consP_PP1_PF1+consP_PP1_PF2+consP_PP2_PF1+consP_PP2_PF2)/4


gen consP_PP1_FF1=0 if (AP_urnePP1!=.&AP_urne5!=.)
replace consP_PP1_FF1=(AP_urnePP1==AP_urne5) if (AP_urnePP1!=.&AP_urne5!=.)

gen consP_PP1_FF2=0 if (AP_urnePP1!=.&AP_urne6!=.)
replace consP_PP1_FF2=(AP_urnePP1==AP_urne6) if (AP_urnePP1!=.&AP_urne6!=.)

gen consP_PP2_FF1=0 if (AP_urnePP2!=.&AP_urne5!=.)
replace consP_PP2_FF1=(AP_urnePP2==AP_urne5) if (AP_urnePP2!=.&AP_urne5!=.)

gen consP_PP2_FF2=0 if (AP_urnePP2!=.&AP_urne6!=.)
replace consP_PP2_FF2=(AP_urnePP2==AP_urne6) if (AP_urnePP2!=.&AP_urne6!=.)

gen consP_PP3_FF3=0 if Sub_novPP==1& AP_urne5!=.
replace consP_PP3_FF3=(AP_urne_novPP==AP_urne5) if Sub_novPP==1& AP_urne5!=.
gen consP_PP_FF=(consP_PP1_FF1+consP_PP1_FF2+consP_PP2_FF1+consP_PP2_FF2)/4

gen consP_PF1_FF1=(AP_urnePF1==AP_urne5) if (AP_urnePF1!=.&AP_urne5!=.)
gen consP_PF1_FF2=(AP_urnePF1==AP_urne6) if (AP_urnePF1!=.&AP_urne6!=.)
gen consP_PF2_FF1=(AP_urnePF2==AP_urne5) if (AP_urnePF2!=.&AP_urne5!=.)
gen consP_PF2_FF2=(AP_urnePF2==AP_urne6) if (AP_urnePF2!=.&AP_urne6!=.)
gen consP_PF3_FF3=(AP_urne_novPF==AP_urne5) if Sub_novPF==1 & AP_urne5!=.
gen consP_PF_FF=(consP_PF1_FF1+consP_PF1_FF2+consP_PF2_FF1+consP_PF2_FF2)/4

gen consP_PP=(AP_urnePP1==AP_urnePP2) if (AP_urnePP1!=.&AP_urnePP2!=.)
gen consP_PF=(AP_urnePF1==AP_urnePF2) if (AP_urnePF1!=.&AP_urnePF2!=.)
gen consP_FF=(AP_urne5==AP_urne6) if (AP_urne5!=.&AP_urne6!=.)

label variable consP_tot "1 if subjects have same Ambgty Pref over all urns"
label variable consP_1_2_4 "1 if subjects have same Ambgty Pref over urns 1 2 4"
label variable consP_1_2 "1 if subjects have same Ambgty Pref over urns 1 2"
label variable consP_1_3 "1 if subjects have same Ambgty Pref over urns 1 3"
label variable consP_1_4 "1 if subjects have same Ambgty Pref over urns 1 4"
label variable consP_2_3 "1 if subjects have same Ambgty Pref over urns 2 3"
label variable consP_2_4 "1 if subjects have same Ambgty Pref over urns 2 4"
label variable consP_3_4 "1 if subjects have same Ambgty Pref over urns 3 4"

label variable consP_PP1_PF1 "1 if subjects have same Ambgty Pref over urns PP1 and PF1"
label variable consP_PP1_PF2 "1 if subjects have same Ambgty Pref over urns PP1 and PF2"
label variable consP_PP2_PF1 "1 if subjects have same Ambgty Pref over urns PP2 and PF1"
label variable consP_PP2_PF2 "1 if subjects have same Ambgty Pref over urns PP2 and PF2"
label variable consP_PP3_PF3 "1 if subjects have same Ambgty Pref PP-PF over identical urn (NOV-NOV)"

label variable consP_PP1_FF1 "1 if subjects have same Ambgty Pref over urns PP1 and FF1"
label variable consP_PP1_FF2 "1 if subjects have same Ambgty Pref over urns PP1 and FF2"
label variable consP_PP2_FF1 "1 if subjects have same Ambgty Pref over urns PP2 and FF1"
label variable consP_PP2_FF2 "1 if subjects have same Ambgty Pref over urns PP2 and FF2"
label variable consP_PP3_FF3 "1 if subjects have same Ambgty Pref over PP-FF phys ident urn (NOV-JAN)"

label variable consP_PF1_FF1 "1 if subjects have same Ambgty Pref over urns PF1 and FF1"
label variable consP_PF1_FF2 "1 if subjects have same Ambgty Pref over urns PF1 and FF2"
label variable consP_PF2_FF1 "1 if subjects have same Ambgty Pref over urns PF2 and FF1"
label variable consP_PF2_FF2 "1 if subjects have same Ambgty Pref over urns PF2 and FF2"
label variable consP_PF3_FF3 "1 if subjects have same Ambgty Pref over PF-FF phys ident urn (NOV-JAN)"

label variable consP_PP "1 if subjects have same Ambgty Pref over PP urns"
label variable consP_PF "1 if subjects have same Ambgty Pref over PF urns"
label variable consP_FF "1 if subjects have same Ambgty Pref over FF urns"

* Number of urn pairs with stable preferences
* Problem: A subject could be consitent over two urns twice (u1=u2 and u3=u4)
egen consP_num=rowmean(consP_1_2 consP_1_3 consP_1_4 consP_2_3 consP_2_4 consP_3_4)
replace consP_num= consP_num*6 
label variable consP_num "Number of urn pairs with the same Amgty prefs"



**********************************************************
* Quality of choices: WTA and Likert Scale
**********************************************************

egen paytochange_mean = rowmean(paytochange*)
label variable paytochange_mean "mean of paytochange over both decisions for ALL urns"

egen paytochange_sd= rowsd(paytochange*)
label variable paytochange_sd "sd of paytochange over both decisions for ALL urns"

egen lkturne_mean = rowmean(lkturne*)
label variable lkturne_mean "mean of lkturne over both decisions for ALL urns"

egen lkturne_sd= rowsd(lkturne*)
label variable lkturne_sd "sd of lkturne over both decisions for ALL urns"

cd "$path"
save labdata.dta, replace



**********************************************************
* APPEND September data
**********************************************************

import excel Labdata_raw_sep, sheet("Labdata") firstrow clear


**********************************************************
* Genereal Comments
**********************************************************

* chosen urns in coin are urn 2 un session 3 and urn 2 in session 6 
* paytochange is rounded to 0.25 in Full, to 0.5 in COIN (This is the smallest marker on the grid of the sheet)
* Likert scales 0 to 4, with 0 ="ueberhaupt nicht sicher and 4 sehr sicher"
**********************************************************
* recode missings
**********************************************************
* Set missings to zero
recode student econmajor semester game statistics econometrics height (. = 0)

**********************************************************
* label variables
**********************************************************
foreach i in 11 12 21 22 31 32 41 42{
label variable urne`i' "Choice urn`i', 1=up, 0=down"
label variable lkturne`i' "Likert scale urn`i', 0=not sure, 4=sure"
label variable paytochange`i' "Willingess to pay for changing bet in urn `i'"
}

foreach i in yearofbirth male student econmajor game statistics econometrics {
label variable `i' "1 if `i'"
}

label variable semester "Semester"
label variable height "Body height in cm"
label variable session "Session"
label variable student "1 if student"
label variable numbercorrectcontrol "Number of correct control questions"
 
label variable hl1 "HL1, choose B first in row X, non-rational prefs=."
label variable hl1_inconsistent "HL1 non-rational"
label variable hl1_confused "HL1, choose option A in row 10"

label variable hl2 "HL2, choose B first in row X, non-rational prefs=."
label variable hl2_inconsistent "HL2 non-rational"
label variable hl2_confused "HL2, choose option A in row 10"

gen id= session*100+index
label variable id "Unique subject id"

gen yob_mis=yearofbirth
label variable yob_mis "Year of birth, yob missing=0"
replace yob_mis=0 if yearofbirth==.

gen yob_misd=(yob_mis==0)
label variable yob_misd "Year of birth missing=1"

**********************************************************
* Generate dummy variables
**********************************************************
foreach i in 1 2 3 4{
gen AA_urne`i'=(urne`i'1==1&urne`i'2==0) //ambiguity averse choice in urn i
label variable AA_urne`i' "Ambiguity averse choice in urn `i'"

gen AN_urne`i'=((urne`i'1==1&urne`i'2==1)|(urne`i'1==0&urne`i'2==0)) //ambiguity neutral choice in urn i
label variable AN_urne`i' "Ambiguity neutral choice in urn `i'"

gen AL_urne`i'=((urne`i'1==0&urne`i'2==1)) //ambiguity loving choice in urn i
label variable AL_urne`i' "Ambiguity loving choice in urn `i'"

gen AP_urne`i'=.
replace AP_urne`i'=-1 if  AA_urne`i'==1
replace AP_urne`i'=0 if  AN_urne`i'==1
replace AP_urne`i'=1 if  AL_urne`i'==1
label variable AP_urne`i' "Ambiguity Preference in urn `i'"
}

**********************************************************
* Generate more dummy variables
**********************************************************
gen cons_tot=(urne11==urne21&urne21==urne41&urne31==urne41&urne12==urne22&urne22==urne42&urne32==urne42)
label variable cons_tot "1 if subjects have same chioce over all urns"

gen cons_1_2_4=(urne11==urne21&urne21==urne41&urne12==urne22&urne22==urne42)
label variable cons_1_2_4 "1 if subjects have same chioce over urns 1 2 4"


gen cons_1_2=(urne11==urne21&urne12==urne22)
gen cons_2_3=(urne21==urne31&urne32==urne22)
gen cons_3_4=(urne31==urne41&urne32==urne42)

label variable cons_1_2 "1 if subjects have same chioce over urns 1 2"
label variable cons_2_3 "1 if subjects have same chioce over urns 2 3"
label variable cons_3_4 "1 if subjects have same chioce over urns 3 4"

gen AA_b1=(urne11==1 &  urne12==0)
gen AA_b2=(urne21==1 &  urne22==0)
gen AA_b3=(urne31==1 &  urne32==0)
gen AA_b4=(urne41==1 &  urne42==0)

gen AL_b1=(urne11==0 &  urne12==1)
gen AL_b2=(urne21==0 &  urne22==1)
gen AL_b3=(urne31==0 &  urne32==1)
gen AL_b4=(urne41==0 &  urne42==1)

gen consAA_tot=(AA_b1==AA_b2&AA_b1==AA_b3&AA_b3==AA_b4)
gen consAA_1_2_4=(AA_b1==AA_b2&AA_b1==AA_b4)
gen consAA_1_2=(AA_b1==AA_b2)
gen consAA_1_3=(AA_b1==AA_b3)
gen consAA_1_4=(AA_b1==AA_b4)
gen consAA_2_3=(AA_b2==AA_b3)
gen consAA_2_4=(AA_b2==AA_b4)
gen consAA_3_4=(AA_b3==AA_b4)

label variable consAA_tot "1 if subjects have Ambgty Pref over all urns"
label variable consAA_1_2_4 "1 if subjects have Ambgty Pref over urns 1 2 4"
label variable consAA_1_2 "1 if subjects have Ambgty Pref over urns 1 2"
label variable consAA_1_3 "1 if subjects have Ambgty Pref over urns 1 3"
label variable consAA_1_4 "1 if subjects have Ambgty Pref over urns 1 4"
label variable consAA_2_3 "1 if subjects have Ambgty Pref over urns 2 3"
label variable consAA_2_4 "1 if subjects have Ambgty Pref over urns 2 4"
label variable consAA_3_4 "1 if subjects have Ambgty Pref over urns 3 4"

gen consP_1_2=(AP_urne1==AP_urne2)
gen consP_1_3=(AP_urne1==AP_urne3)
gen consP_1_4=(AP_urne1==AP_urne4)
gen consP_2_3=(AP_urne2==AP_urne3)
gen consP_2_4=(AP_urne2==AP_urne4)
gen consP_3_4=(AP_urne3==AP_urne4)

label variable consP_1_2 "1 if subjects have Ambgty Pref over urns 1 2"
label variable consP_1_3 "1 if subjects have Ambgty Pref over urns 1 3"
label variable consP_1_4 "1 if subjects have Ambgty Pref over urns 1 4"
label variable consP_2_3 "1 if subjects have Ambgty Pref over urns 2 3"
label variable consP_2_4 "1 if subjects have Ambgty Pref over urns 2 4"
label variable consP_3_4 "1 if subjects have Ambgty Pref over urns 3 4"

gen hl_outlier=(hl1_inconsistent==1|hl1_confused==1|hl2_inconsistent==1|hl2_confused==1)
label variable hl_outlier "1 if in hlx inconsistent or confused"

* Note this variable accounts for the fact that subjects could be indifferent between two rows
* Inconsistency is definded s.t. deviation between 1st and 2nd choice is greater 2
gen hl_consistent=((abs(hl1-hl2)<=1)&hl_outlier==0)
label variable hl_consistent "HL is consistent s.t. abs(hl1-hl2)<2"

egen paytochange_mean = rowmean(paytochange*)
label variable paytochange_mean "mean of paytochange over both decisions for ALL urns"

egen paytochange_sd= rowsd(paytochange*)
label variable paytochange_sd "sd of paytochange over both decisions for ALL urns"

egen lkturne_mean = rowmean(lkturne*)
label variable lkturne_mean "mean of lkturne over both decisions for ALL urns"

egen lkturne_sd= rowsd(lkturne*)
label variable lkturne_sd "sd of lkturne over both decisions for ALL urns"

**********************************************************
* Number of consistent choices
**********************************************************
* Problem: A subject could be consitent over two urns twice (u1=u2 and u3=u4)
egen consAA_num=rowmean(consAA_1_2 consAA_1_3 consAA_1_4 consAA_2_3 consAA_2_4 consAA_3_4)
replace consAA_num= consAA_num*6 
label variable consAA_num "Number of urns with the same Amgty prefs"

save interim, replace



use labdata.dta, clear


rename hl_inconsistent hl1_inconsistent
rename hl_confused  hl1_confused
rename hl_jan_inconsistent hl2_inconsistent
rename hl_jan_confused hl2_confused
rename hl hl1
rename hl_jan hl2


********************************************************************
* Go back to append data
******************************************************************** 

append using interim.dta

drop if full==1   //Drop sep subjects from full treatment, only keeping coin

cd "$path"

replace  id_sep=. if  id_sep<300

replace Id=Id+10000

replace Id=id if Id==.         //bertragen der id aus sep datensatz in Id variable
replace Id=id_sep if id_sep!=.  //Nov subjects die eine id_sep haben, werden mit id_sep identifiziert


drop payoff pre_sub payoff_jan hl_outlier hl_jan_outlier
drop index full lfdnr id yob_misd coin


gen coin=0
replace coin=1 if platznummer==.
label variable coin "Treatment Coin September"
replace pilot=0 if coin==1

gen consP_tot_noPF=0 if  AP_urne5!=.&AP_urne6!=.& AP_urnePP1!=.& AP_urnePP2!=.
replace consP_tot_noPF=1 if (AP_urne5==AP_urne6& AP_urnePP1==AP_urnePP2 & AP_urne5==AP_urnePP1)&(AP_urne5!=.&AP_urne6!=.& AP_urnePP1!=.& AP_urnePP2!=.)

replace consP_tot_noPF=0 if (AP_urne1!=.&AP_urne2!=.& AP_urne3!=.& AP_urne4!=.)&coin==1
replace consP_tot_noPF=1 if (AP_urne1==AP_urne2& AP_urne3==AP_urne4 & AP_urne1==AP_urne3)&(AP_urne1!=.&AP_urne2!=.& AP_urne3!=.& AP_urne4!=.)&coin==1

label variable consP_tot_noPF "Same pref over PP1, PP2, FF1, FF2 or urne1, urne2, urne3, urne4"



save labdata_sep_nov_jan.dta, replace



**********************************************************
* Stacked dataset
**********************************************************

**********************************************************
* Reorganize dataset
**********************************************************
clear
foreach i in PP1 PP2 PP3 PF1 PF2 PF3{
use labdata_sep_nov_jan.dta, clear
*keep number* hl* lkturne_* paytochange_* paytochange`i'* urne`i'1 urne`i'2 lkturne`i'1 lkturne`i'2 AA_urne`i' AN_urne`i' AL_urne`i' AP_urne`i' id hl* year *yob* male student econmajor semester game statistics econometrics height 

keep id_sep coin sep Id hl* paytochange`i'* urne`i'1 urne`i'2 lkt`i'1 lkt`i'2 AA_urne`i' AN_urne`i' AL_urne`i' AP_urne`i' session rando* id discount yearofbirth male student econmajor semester game econometrics statistics height session_jan
drop if coin==1

gen urn_id="`i'"
label variable urn_id "label of urn"

rename urne`i'1 urne1 

rename urne`i'2 urne2
rename lkt`i'1 lkt1 
rename lkt`i'2 lkt2
rename paytochange`i'1 paytochange1
rename paytochange`i'2 paytochange2
rename AA_urne`i' AA 
rename AN_urne`i' AN
rename AL_urne`i' AL
rename AP_urne`i' AP

gen urn_nb=.
replace urn_nb=1 if randomization==0 & urn_id=="PP1"
replace urn_nb=2 if randomization==0 & urn_id=="PP2"
replace urn_nb=3 if randomization==0 & urn_id=="PF1"
replace urn_nb=4 if randomization==0 & urn_id=="PF2"
replace urn_nb=1 if randomization==1 & urn_id=="PF1"
replace urn_nb=2 if randomization==1 & urn_id=="PF2"
replace urn_nb=3 if randomization==1 & urn_id=="PP1"
replace urn_nb=4 if randomization==1 & urn_id=="PP2"
label variable urn_nb "nb of urn in experiment"

gen future=(urn_id=="PF1"|urn_id=="PF2")
label variable future "1 if future urn"



save urne`i'.dta, replace
}


foreach i in 5 6{
use labdata_sep_nov_jan.dta, clear
keep id_sep coin sep  Id hl* paytochange`i'* urne`i'1 urne`i'2 lkturne`i'1 lkturne`i'2 AA_urne`i' AN_urne`i' AL_urne`i' AP_urne`i' session rando* id discount yearofbirth male student econmajor semester game econometrics statistics height session_jan
drop if coin==1

gen urn_id="`i'"
label variable urn_id "label of urn"

rename urne`i'1 urne1 

rename urne`i'2 urne2
rename lkturne`i'1 lkt1 
rename lkturne`i'2 lkt2
rename paytochange`i'1 paytochange1
rename paytochange`i'2 paytochange2
rename AA_urne`i' AA 
rename AN_urne`i' AN
rename AL_urne`i' AL
rename AP_urne`i' AP

gen urn_nb=.
replace urn_nb=`i' 

label variable urn_nb "nb of urn in experiment"

save urne`i'.dta, replace
}


* Stack September data

use labdata_sep_nov_jan.dta, clear

* urne 1
*rename Id sep_Id
keep if coin==1

gen urn_id="sep"
label variable urn_id "id of urn"
gen urn_nb=1

rename urne11 urne1 
rename urne12 urne2
rename lkturne11 lkt1 
rename lkturne12 lkt2
rename paytochange11 paytochange1
rename paytochange12 paytochange2
rename AA_urne1 AA 
rename AN_urne1 AN
rename AL_urne1 AL
rename AP_urne1 AP


save urnesep1.dta, replace

* urne 2
use labdata_sep_nov_jan.dta, clear
*rename Id sep_Id
keep if coin==1

gen urn_id="sep"
label variable urn_id "id of urn"
gen urn_nb=2

rename urne21 urne1 
rename urne22 urne2
rename lkturne21 lkt1 
rename lkturne22 lkt2
rename paytochange21 paytochange1
rename paytochange22 paytochange2
rename AA_urne2 AA 
rename AN_urne2 AN
rename AL_urne2 AL
rename AP_urne2 AP

save urnesep2.dta, replace



* urne 3
*rename Id sep_Id
use labdata_sep_nov_jan.dta, clear
keep if coin==1

gen urn_id="sep"
label variable urn_id "id of urn"
gen urn_nb=3

rename urne31 urne1 
rename urne32 urne2
rename lkturne31 lkt1 
rename lkturne32 lkt2
rename paytochange31 paytochange1
rename paytochange32 paytochange2
rename AA_urne3 AA 
rename AN_urne3 AN
rename AL_urne3 AL
rename AP_urne3 AP

save urnesep3.dta, replace

* urne 4
use labdata_sep_nov_jan.dta, clear
*rename Id sep_Id
keep if coin==1

gen urn_id="sep"
label variable urn_id "id of urn"
gen urn_nb=4

rename urne41 urne1 
rename urne42 urne2
rename lkturne41 lkt1 
rename lkturne42 lkt2
rename paytochange41 paytochange1
rename paytochange42 paytochange2
rename AA_urne4 AA 
rename AN_urne4 AN
rename AL_urne4 AL
rename AP_urne4 AP

save urnesep4.dta, replace

clear




use urnePP1.dta, clear
foreach i in  PP2 PP3 PF1 PF2 PF3 sep1 sep2 sep3 sep4 5 6 {
append using urne`i'.dta 
}


foreach i in 1 2{
label variable urne`i' "Choice `i', 1=up, 0=down"
label variable lkt`i' "Likert scale choice `i', 0=not sure, 4=sure"
label variable paytochange`i' "Willingess to pay for changing bet in choice `i'"
label variable AN "1 if subject is AN"
label variable AA "1 if subject is AA"
label variable AL "1 if subject is AL"
label variable AP "Ambiguity prefs 1=AL, 0=AN, -1=AA"
}


*drop sep_*
*drop pilot_*
drop if AP==.&urn_id=="sep"
*drop if AP==.&urn_id=="pilot"

*gen pilot_urn=(urn_id=="pilot")
*label variable pilot_urn "1 if pilot sub"

gen sep_urn=(urn_id=="sep")
label variable sep_urn "1 if september sub"

save stacked_labdata.dta, replace

foreach i in  PP1 PP2 PP3 PF1 PF2 PF3 sep1 sep2 sep3 sep4 5 6{
erase urne`i'.dta
}


**********************************************************
* Stacked dataset Nov - Jan & coin from Sep
**********************************************************

use stacked_labdata.dta, clear


drop if urn_id=="pilot"
drop if urn_id=="PF3"
drop if urn_id=="PP3"
drop if urn_id=="5"
drop if urn_id=="6"


tab urn_nb, gen(urn_nb_)
tab randomization, gen(rand_)

gen rand_d=(randomization==.)
replace randomization=0 if randomization==.

cd "$path"
save stacked_labdata_order.dta, replace


cd "$path"

*******************
* PP-PF 
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP1!=.&AP_urnePF1!=.&coin==0
replace cons=(AP_urnePP1==AP_urnePF1) if AP_urnePP1!=.&AP_urnePF1!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP1 if AP_urnePP1!=.&AP_urnePF1!=.&coin==0
replace AP_after=AP_urnePF1 if AP_urnePP1!=.&AP_urnePF1!=.&coin==0

replace lkt_mean=(lktPP11+lktPP12+lktPF11+lktPF12)/4 if lktPP11!=. & lktPP12!=. & lktPF11!=. & lktPF12!=.
replace paytochange_mean=(paytochangePP11+paytochangePP12+paytochangePF11+paytochangePF12)/4 if paytochangePP11!=. & paytochangePP12!=. & paytochangePF11!=. & paytochangePF12!=.
gen comparison="PP1-PF1" if cons!=.
gen ident=0 if cons!=.
replace ident=1 if session==1|session==6
gen lkt_cons=(lktPP11==lktPF11& lktPP12==lktPF12) if lkt_mean!=.
gen ptc_cons=(paytochangePP11==paytochangePF11& paytochangePP12==paytochangePF12) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison lkt_cons ptc_cons rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons1.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP1!=.&AP_urnePF2!=.&coin==0
replace cons=(AP_urnePP1==AP_urnePF2) if AP_urnePP1!=.&AP_urnePF2!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP1 if AP_urnePP1!=.&AP_urnePF2!=.&coin==0
replace AP_after=AP_urnePF2 if AP_urnePP1!=.&AP_urnePF2!=.&coin==0

replace lkt_mean=(lktPP11+lktPP12+lktPF21+lktPF22)/4 if lktPP11!=. & lktPP12!=. & lktPF21!=. & lktPF22!=.
replace paytochange_mean=(paytochangePP11+paytochangePP12+paytochangePF21+paytochangePF22)/4 if paytochangePP11!=. & paytochangePP12!=. & paytochangePF21!=. & paytochangePF22!=.
gen comparison="PP1-PF2" if cons!=.
gen ident=0 if cons!=.
replace ident=1 if session==4
gen lkt_cons=(lktPP11==lktPF21& lktPP12==lktPF22) if lkt_mean!=.
gen ptc_cons=(paytochangePP11==paytochangePF21& paytochangePP12==paytochangePF22) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons2.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP2!=.&AP_urnePF1!=.&coin==0
replace cons=(AP_urnePP2==AP_urnePF1) if AP_urnePP2!=.&AP_urnePF1!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP2 if AP_urnePP2!=.&AP_urnePF1!=.&coin==0
replace AP_after=AP_urnePF1 if AP_urnePP2!=.&AP_urnePF1!=.&coin==0

replace lkt_mean=(lktPP21+lktPP22+lktPF11+lktPF12)/4 if lktPP21!=. & lktPP22!=. & lktPF11!=. & lktPF12!=.
replace paytochange_mean=(paytochangePP21+paytochangePP22+paytochangePF11+paytochangePF12)/4 if paytochangePP21!=. & paytochangePP22!=. & paytochangePF11!=. & paytochangePF12!=.
gen comparison="PP2-PF1" if cons!=.
gen ident=0 if cons!=.
replace ident=1 if session==2|session==3
gen lkt_cons=(lktPP21==lktPF11& lktPP22==lktPF12) if lkt_mean!=.
gen ptc_cons=(paytochangePP21==paytochangePF11& paytochangePP22==paytochangePF12) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons3.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP2!=.&AP_urnePF2!=.&coin==0
replace cons=(AP_urnePP2==AP_urnePF2) if AP_urnePP2!=.&AP_urnePF2!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP2 if AP_urnePP2!=.&AP_urnePF2!=.&coin==0
replace AP_after=AP_urnePF2 if AP_urnePP2!=.&AP_urnePF2!=.&coin==0

replace lkt_mean=(lktPP21+lktPP22+lktPF21+lktPF22)/4 if lktPP21!=. & lktPP22!=. & lktPF21!=. & lktPF22!=.
replace paytochange_mean=(paytochangePP21+paytochangePP22+paytochangePF21+paytochangePF22)/4 if paytochangePP21!=. & paytochangePP22!=. & paytochangePF21!=. & paytochangePF22!=.
gen comparison="PP2-PF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 if session==1|session==6 //kommt nicht als identische Urne vor
gen lkt_cons=(lktPP21==lktPF21& lktPP22==lktPF22) if lkt_mean!=.
gen ptc_cons=(paytochangePP21==paytochangePF21& paytochangePP22==paytochangePF22) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons4.dta,replace

*******************
* PP-FF 
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP1!=.&AP_urne5!=.&coin==0
replace cons=(AP_urnePP1==AP_urne5) if AP_urnePP1!=.&AP_urne5!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP1 if AP_urnePP1!=.&AP_urne5!=.&coin==0
replace AP_after=AP_urne5 if AP_urnePP1!=.&AP_urne5!=.&coin==0

replace lkt_mean=(lktPP11+lktPP12+lkturne51+lkturne52)/4 if lktPP11!=. & lktPP12!=. & lkturne51!=. & lkturne52!=.
replace paytochange_mean=(paytochangePP11+paytochangePP12+paytochange51+paytochange52)/4 if paytochangePP11!=. & paytochangePP12!=. & paytochange51!=. & paytochange52!=.
gen comparison="PP1-FF1" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 if session==1|session==6 //kommt nicht als identische Urne vor
gen lkt_cons=(lktPP11==lkturne51& lktPP12==lkturne52) if lkt_mean!=.
gen ptc_cons=(paytochangePP11==paytochange51& paytochangePP12==paytochange52) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons5.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP1!=.&AP_urne6!=.&coin==0
replace cons=(AP_urnePP1==AP_urne6) if AP_urnePP1!=.&AP_urne6!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP1 if AP_urnePP1!=.&AP_urne6!=.&coin==0
replace AP_after=AP_urne6 if AP_urnePP1!=.&AP_urne6!=.&coin==0

replace lkt_mean=(lktPP11+lktPP12+lkturne61+lkturne62)/4 if lktPP11!=. & lktPP12!=. & lkturne61!=. & lkturne62!=.
replace paytochange_mean=(paytochangePP11+paytochangePP12+paytochange61+paytochange62)/4 if paytochangePP11!=. & paytochangePP12!=. & paytochange61!=. & paytochange62!=.
gen comparison="PP1-FF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 if session==4 //kommt nicht als identische Urne vor
gen lkt_cons=(lktPP11==lkturne61& lktPP12==lkturne62) if lkt_mean!=.
gen ptc_cons=(paytochangePP11==paytochange61& paytochangePP12==paytochange62) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons6.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP2!=.&AP_urne5!=.&coin==0
replace cons=(AP_urnePP2==AP_urne5) if AP_urnePP2!=.&AP_urne5!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP2 if AP_urnePP2!=.&AP_urne5!=.&coin==0
replace AP_after=AP_urne5 if AP_urnePP2!=.&AP_urne5!=.&coin==0

replace lkt_mean=(lktPP21+lktPP22+lkturne51+lkturne52)/4 if lktPP21!=. & lktPP22!=. & lkturne51!=. & lkturne52!=.
replace paytochange_mean=(paytochangePP21+paytochangePP22+paytochange51+paytochange52)/4 if paytochangePP21!=. & paytochangePP22!=. & paytochange51!=. & paytochange52!=.
gen comparison="PP2-FF1" if cons!=.
gen ident=0 if cons!=.
replace ident=1 if session==1|session==2|session==3|session==4|session==5
gen lkt_cons=(lktPP21==lkturne51& lktPP22==lkturne52) if lkt_mean!=.
gen ptc_cons=(paytochangePP21==paytochange51& paytochangePP22==paytochange52) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons7.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP2!=.&AP_urne6!=.&coin==0
replace cons=(AP_urnePP2==AP_urne6) if AP_urnePP2!=.&AP_urne6!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP2 if AP_urnePP2!=.&AP_urne6!=.&coin==0
replace AP_after=AP_urne6 if AP_urnePP2!=.&AP_urne6!=.&coin==0

replace lkt_mean=(lktPP21+lktPP22+lkturne61+lkturne62)/4 if lktPP21!=. & lktPP22!=. & lkturne61!=. & lkturne62!=.
replace paytochange_mean=(paytochangePP21+paytochangePP22+paytochange61+paytochange62)/4 if paytochangePP21!=. & paytochangePP22!=. & paytochange61!=. & paytochange62!=.
gen comparison="PP2-FF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 if session==1|session==6 //kommt nicht als identische Urne vor
gen lkt_cons=(lktPP21==lkturne61& lktPP22==lkturne62) if lkt_mean!=.
gen ptc_cons=(paytochangePP21==paytochange61& paytochangePP22==paytochange62) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons8.dta,replace
clear



*******************
* PF-FF
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePF1!=.&AP_urne5!=.&coin==0
replace cons=(AP_urnePF1==AP_urne5) if AP_urnePF1!=.&AP_urne5!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePF1 if AP_urnePF1!=.&AP_urne5!=.&coin==0
replace AP_after=AP_urne5 if AP_urnePF1!=.&AP_urne5!=.&coin==0

replace lkt_mean=(lktPF11+lktPF12+lkturne51+lkturne52)/4 if lktPF11!=. & lktPF12!=. & lkturne51!=. & lkturne52!=.
replace paytochange_mean=(paytochangePF11+paytochangePF12+paytochange51+paytochange52)/4 if paytochangePF11!=. & paytochangePF12!=. & paytochange51!=. & paytochange52!=.
gen comparison="PF1-FF1" if cons!=.
gen ident=0 if cons!=.
replace ident=1 if session==2|session==3
gen lkt_cons=(lktPF11==lkturne51& lktPF12==lkturne52) if lkt_mean!=.
gen ptc_cons=(paytochangePP11==paytochange51& paytochangePP12==paytochange52) if paytochange_mean!=.
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons9.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePF1!=.&AP_urne6!=.&coin==0
replace cons=(AP_urnePF1==AP_urne6) if AP_urnePF1!=.&AP_urne6!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePF1 if AP_urnePF1!=.&AP_urne6!=.&coin==0
replace AP_after=AP_urne6  if AP_urnePF1!=.&AP_urne6!=.&coin==0

replace lkt_mean=(lktPF11+lktPF12+lkturne61+lkturne62)/4 if lktPF11!=. & lktPF12!=. & lkturne61!=. & lkturne62!=.
replace paytochange_mean=(paytochangePF11+paytochangePF12+paytochange61+paytochange62)/4 if paytochangePF11!=. & paytochangePF12!=. & paytochange61!=. & paytochange62!=.
gen comparison="PF1-FF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 if session==4 //kommt nicht als identische Urne vor
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons10.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePF2!=.&AP_urne5!=.&coin==0
replace cons=(AP_urnePF2==AP_urne5) if AP_urnePF2!=.&AP_urne5!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePF2 if AP_urnePF2!=.&AP_urne5!=.&coin==0
replace AP_after=AP_urne5 if AP_urnePF2!=.&AP_urne5!=.&coin==0

replace lkt_mean=(lktPF21+lktPF22+lkturne51+lkturne52)/4 if lktPF21!=. & lktPF22!=. & lkturne51!=. & lkturne52!=.
replace paytochange_mean=(paytochangePF21+paytochangePF22+paytochange51+paytochange52)/4 if paytochangePF21!=. & paytochangePF22!=. & paytochange51!=. & paytochange52!=.
gen comparison="PF2-FF1" if cons!=.
gen ident=0 if cons!=.
replace ident=1 if session==6
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons11.dta,replace

use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePF2!=.&AP_urne6!=.&coin==0
replace cons=(AP_urnePF2==AP_urne6) if AP_urnePF2!=.&AP_urne6!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePF2 if AP_urnePF2!=.&AP_urne6!=.&coin==0
replace AP_after=AP_urne6 if AP_urnePF2!=.&AP_urne6!=.&coin==0

replace lkt_mean=(lktPF21+lktPF22+lkturne61+lkturne62)/4 if lktPF21!=. & lktPF22!=. & lkturne61!=. & lkturne62!=.
replace paytochange_mean=(paytochangePF21+paytochangePF22+paytochange61+paytochange62)/4 if paytochangePF21!=. & paytochangePF22!=. & paytochange61!=. & paytochange62!=.
gen comparison="PF2-FF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 if session==1|session==6 //kommt nicht als identische Urne vor
keep Id cons AP_before AP_after ident rando* coin comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons12.dta,replace


*******************
* PP-PP 
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePP1!=.&AP_urnePP2!=.&coin==0
replace cons=(AP_urnePP1==AP_urnePP2) if AP_urnePP1!=.&AP_urnePP2!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePP1 if AP_urnePP1!=.&AP_urnePP2!=.&coin==0
replace AP_after=AP_urnePP2 if AP_urnePP1!=.&AP_urnePP2!=.&coin==0

replace lkt_mean=(lktPP11+lktPP12+lktPP21+lktPP22)/4 if lktPP11!=. & lktPP12!=. & lktPP21!=. & lktPP22!=.
replace paytochange_mean=(paytochangePP11+paytochangePP12+paytochangePP21+paytochangePP22)/4 if paytochangePP11!=. & paytochangePP12!=. & paytochangePP21!=. & paytochangePP22!=.
gen comparison="PP1-PP2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 ist nie ident
keep Id cons AP_before AP_after ident coin rando* comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons13.dta,replace


*******************
* PF-PF 
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urnePF1!=.&AP_urnePF2!=.&coin==0
replace cons=(AP_urnePF1==AP_urnePF2) if AP_urnePF1!=.&AP_urnePF2!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urnePF1 if AP_urnePF1!=.&AP_urnePF2!=.&coin==0
replace AP_after=AP_urnePF2 if AP_urnePF1!=.&AP_urnePF2!=.&coin==0

replace lkt_mean=(lktPF11+lktPF12+lktPF21+lktPF22)/4 if lktPF11!=. & lktPF12!=. & lktPF21!=. & lktPF22!=.
replace paytochange_mean=(paytochangePF11+paytochangePF12+paytochangePF21+paytochangePF22)/4 if paytochangePF11!=. & paytochangePF12!=. & paytochangePF21!=. & paytochangePF22!=.
gen comparison="PF1-PF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 ist nie ident
keep Id cons AP_before AP_after ident coin rando* comparison rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons14.dta,replace

*******************
* FF-FF 
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne5!=.&AP_urne6!=.&coin==0
replace cons=(AP_urne5==AP_urne6) if AP_urne5!=.&AP_urne6!=.&coin==0

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne5 if AP_urne5!=.&AP_urne6!=.&coin==0
replace AP_after=AP_urne6 if AP_urne5!=.&AP_urne6!=.&coin==0

replace lkt_mean=(lkturne51+lkturne52+lkturne61+lkturne62)/4 if lkturne51!=. & lkturne52!=. & lkturne61!=. & lkturne62!=.
replace paytochange_mean=(paytochange51+paytochange52+paytochange61+paytochange62)/4 if paytochange51!=. & paytochange52!=. & paytochange61!=. & paytochange62!=.
gen comparison="FF1-FF2" if cons!=.
gen ident=0 if cons!=.
* replace ident=1 ist nie ident
keep comparison Id cons AP_before AP_after coin  rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons15.dta,replace
clear




*******************
* Fs1-Fs2
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne3!=.&AP_urne4!=.&coin==1
replace cons=(AP_urne3==AP_urne4) if AP_urne3!=.&AP_urne4!=.&coin==1

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne3 if AP_urne3!=.&AP_urne4!=.&coin==1
replace AP_after=AP_urne4 if AP_urne3!=.&AP_urne4!=.&coin==1

replace lkt_mean=(lkturne31+lkturne32+lkturne41+lkturne42)/4 if lkturne31!=. & lkturne32!=. & lkturne41!=. & lkturne42!=. &coin==1
replace paytochange_mean=(paytochange31+paytochange32+paytochange41+paytochange42)/4 if paytochange31!=. & paytochange32!=. & paytochange41!=. & paytochange42!=. &coin==1
gen comparison="Fs1-Fs2" if cons!=.
gen ident=0 if cons!=. 
* Innerhalb einer choice condition sind urnen nie identisch
keep comparison AP_before AP_after Id cons coin rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons20.dta,replace
clear



*******************
* Ps1-Fs2
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne1!=.&AP_urne4!=.&coin==1
replace cons=(AP_urne1==AP_urne4) if AP_urne1!=.&AP_urne4!=.&coin==1

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne1 if AP_urne1!=.&AP_urne4!=.&coin==1
replace AP_after=AP_urne4 if AP_urne1!=.&AP_urne4!=.&coin==1

replace lkt_mean=(lkturne11+lkturne12+lkturne41+lkturne42)/4 if lkturne11!=. & lkturne12!=. & lkturne41!=. & lkturne42!=. &coin==1
replace paytochange_mean=(paytochange11+paytochange12+paytochange41+paytochange42)/4 if paytochange11!=. & paytochange12!=. & paytochange41!=. & paytochange42!=. &coin==1
gen comparison="Ps1-Fs2" if cons!=.
gen ident=0 if cons!=. 
* Random draw chooses urn2=urn3, daher ident=0
keep comparison  AP_before AP_after Id cons coin rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons21.dta,replace
clear


*******************
* Ps2-Fs1
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne2!=.&AP_urne3!=.&coin==1
replace cons=(AP_urne2==AP_urne3) if AP_urne2!=.&AP_urne3!=.&coin==1

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne2 if AP_urne2!=.&AP_urne3!=.&coin==1
replace AP_after=AP_urne3 if AP_urne2!=.&AP_urne3!=.&coin==1

replace lkt_mean=(lkturne31+lkturne32+lkturne21+lkturne22)/4 if lkturne31!=. & lkturne32!=. & lkturne21!=. & lkturne22!=. &coin==1
replace paytochange_mean=(paytochange31+paytochange32+paytochange21+paytochange22)/4 if paytochange31!=. & paytochange32!=. & paytochange21!=. & paytochange22!=. &coin==1
gen comparison="Ps2-Fs1" if cons!=.
gen ident=1 if cons!=. 
* Random draw chooses urn2=urn3, daher ident=1
keep comparison AP_before AP_after Id cons coin rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons22.dta,replace
clear

*******************
* Ps1-Fs1
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne1!=.&AP_urne3!=.&coin==1
replace cons=(AP_urne1==AP_urne3) if AP_urne1!=.&AP_urne3!=.&coin==1

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne1 if AP_urne1!=.&AP_urne3!=.&coin==1
replace AP_after=AP_urne3 if AP_urne1!=.&AP_urne3!=.&coin==1

replace lkt_mean=(lkturne31+lkturne32+lkturne11+lkturne12)/4 if lkturne31!=. & lkturne32!=. & lkturne11!=. & lkturne12!=. &coin==1
replace lkt_mean=(paytochange31+paytochange32+paytochange11+paytochange12)/4 if paytochange31!=. & paytochange32!=. & paytochange11!=. & paytochange12!=. &coin==1
gen comparison="Ps1-Fs1" if cons!=.
gen ident=0 if cons!=. 
* Random draw chooses urn2=urn3, daher ident=0
keep comparison  AP_before AP_after Id cons coin rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons23.dta,replace
clear

*******************
* Ps2-Fs2
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne2!=.&AP_urne4!=.&coin==1
replace cons=(AP_urne2==AP_urne4) if AP_urne2!=.&AP_urne4!=.&coin==1

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne2 if AP_urne2!=.&AP_urne4!=.&coin==1
replace AP_after=AP_urne4 if AP_urne2!=.&AP_urne4!=.&coin==1

replace lkt_mean=(lkturne21+lkturne22+lkturne41+lkturne42)/4 if lkturne21!=. & lkturne22!=. & lkturne41!=. & lkturne42!=. &coin==1
replace lkt_mean=(paytochange21+paytochange22+paytochange41+paytochange42)/4 if paytochange21!=. & paytochange22!=. & paytochange41!=. & paytochange42!=. &coin==1
gen comparison="Ps2-Fs2" if cons!=.
gen ident=0 if cons!=. 
* Random draw chooses urn2=urn3, daher ident=0
keep comparison  AP_before AP_after Id cons coin rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons24.dta,replace
clear


*******************
* Ps1-Ps2
*******************
* Generiere Daten
use labdata_sep_nov_jan.dta, clear
gen lkt_mean=.
replace paytochange_mean=.
gen cons=0 if AP_urne1!=.&AP_urne2!=.&coin==1
replace cons=(AP_urne1==AP_urne1) if AP_urne1!=.&AP_urne2!=.&coin==1

gen AP_before=.
gen AP_after=.
replace AP_before=AP_urne1 if AP_urne1!=.&AP_urne2!=.&coin==1
replace AP_after=AP_urne2 if AP_urne1!=.&AP_urne2!=.&coin==1

replace lkt_mean=(lkturne11+lkturne12+lkturne21+lkturne22)/4 if lkturne11!=. & lkturne12!=. & lkturne21!=. & lkturne22!=. &coin==1
replace paytochange_mean=(paytochange11+paytochange12+paytochange21+paytochange22)/4 if paytochange11!=. & paytochange12!=. & paytochange21!=. & paytochange22!=. &coin==1
gen comparison="Ps1-Ps2" if cons!=.
gen ident=0 if cons!=. 
* Innerhalb einer choice condition sind urnen nie identisch
keep comparison  AP_before AP_after Id cons coin rando* ident rem_all5 rem_allPF discount hl1 hl2  yearofbirth male student econmajor semester game statistics econometrics height lkt_mean paytochange_mean
save cons25.dta,replace
clear

use cons1.dta, clear

append using cons2.dta
append using cons3.dta
append using cons4.dta
append using cons5.dta
append using cons6.dta
append using cons7.dta
append using cons8.dta
append using cons9.dta
append using cons10.dta
append using cons11.dta
append using cons12.dta
append using cons13.dta
append using cons14.dta
append using cons15.dta

tabulate comparison, generate(comparison_)

append using cons20.dta
append using cons21.dta
append using cons22.dta
append using cons23.dta
append using cons24.dta
append using cons25.dta

drop if cons==.

gen comparison_20=(comparison=="Fs1-Fs2")
label variable comparison_20 "Fs1-Fs2"
gen comparison_21=(comparison=="Ps1-Fs2")
label variable comparison_21 "Ps1-Fs2"
gen comparison_22=(comparison=="Ps2-Fs1")
label variable comparison_22 "Ps2-Fs1"
gen comparison_23=(comparison=="Ps1-Fs1")
label variable comparison_23 "Ps1-Fs1"
gen comparison_24=(comparison=="Ps2-Fs2")
label variable comparison_24 "Ps2-Fs2"
gen comparison_25=(comparison=="Ps1-Ps2")
label variable comparison_25 "Ps1-Ps2"

gen comparison_16=0
replace comparison_16=1 if comparison=="PP1-PF1"|comparison=="PP1-PF2"|comparison=="PP2-PF1"|comparison=="PP2-PF2"
label variable comparison_16 "PP_PF"


gen comparison_17=0
replace comparison_17=1 if comparison=="PP1-FF1"|comparison=="PP1-FF2"|comparison=="PP2-FF1"|comparison=="PP2-FF2"
label variable comparison_17 "PP_FF"


gen comparison_18=0
replace comparison_18=1 if comparison=="PF1-FF1"|comparison=="PF1-FF2"|comparison=="PF2-FF1"|comparison=="PF2-FF2"
label variable comparison_18 "PF_FF"


gen comparison_19=0
replace comparison_19=1 if comparison=="Ps1-Fs1"|comparison=="Ps1-Fs2"|comparison=="Ps2-Fs1"|comparison=="Ps2-Fs2"|comparison=="PP1-FF1"|comparison=="PP1-FF2"|comparison=="PP2-FF1"|comparison=="PP2-FF2"
label variable comparison_19 "timeeffect"


gen comparison_26=0
replace comparison_26=1 if comparison=="Ps1-Fs1"|comparison=="Ps1-Fs2"|comparison=="Ps2-Fs1"|comparison=="Ps2-Fs2"
label variable comparison_26 "Ps_Fs"

gen samesituation=0
replace samesituation=1 if comparison=="PP1-PP2"|comparison=="PF1-PF2"|comparison=="FF1-FF2"|comparison=="Ps1-Ps2"|comparison=="Fs1-Fs2"
label variable samesituation "Entscheidung auf dem gleichen Entscheidungsblatt"

save cons_stacked_labdata.dta, replace

erase cons1.dta
erase cons2.dta
erase cons3.dta
erase cons4.dta
erase cons5.dta
erase cons6.dta
erase cons7.dta
erase cons8.dta
erase cons9.dta
erase cons10.dta
erase cons11.dta
erase cons12.dta
erase cons13.dta
erase cons14.dta
erase cons15.dta
erase cons20.dta
erase cons21.dta
erase cons22.dta
erase cons23.dta
erase cons24.dta
erase cons25.dta
erase interim.dta

//clear
